
from distutils.core import setup
setup(
  name = 'parski',
  packages = ['parski'],
  version = '2.2.1.75',
  description = 'Helper library for filtering json data',
  author = 'Russell Endicott',
  author_email = 'rendicott@gmail.com',
  keywords = ["vpc", "json", "parski"],
  classifiers = []
)